==> nextcloud-22.0.0-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/circles/l10n/sq.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "Rrethet",
    "You created the circle {circle}" : "Ju krijuar rrethin {circle}",
    "{author} created the circle {circle}" : "{author} krijoi rrethin {circle}",
    "You deleted {circle}" : "Ju fshitë {circle}",
    "{author} deleted {circle}" : "{author} fshiu {circle}",
    "You linked {group} to {circle}" : "Ju lidhët {group} me {circle}",
    "You unlinked {group} from {circle}" : "You shkëputët {group} nga {circle}",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "Ju ndryshuar nivelin e grupit te lidhur {group} në {circle} në %1$s",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} ndryshoi nivelin e grupit të lidhur {group} në {circle} në %1$s",
    "You sent a request to link {circle} with {remote}" : "Ju dërguat një kërkesë për të lidhur {circle} me {remote}",
    "{author} sent a request to link {circle} with {remote}" : "{author} dërgoi një kërkesë për të lidhur{rrethit} me {largët}",
    "{remote} requested a link with {circle}" : "{remote} kërkoi një lidhje me {rrethin}",
    "The request to link {circle} with {remote} has been rejected" : "Kërkesa për të lidhur {circle} me {remote} është refuzuar",
    "The request to link {remote} with {circle} has been canceled remotely" : "Kërkesa për të lidhur {remote} with {circle} është anuluar në distancë",
    "The request to link {circle} with {remote} has been accepted" : "Kërkesa për të lidhur {circle} me {remote} ësht pranuar",
    "You dismissed the request to link {remote} with {circle}" : "Ju hodhët poshtë kërkesën për të lidhur {remote} me {circle}",
    "{author} dismissed the request to link {remote} with {circle}" : "{author} hodhi poshtë kërkesën për të lidhur {remote} me {circle}",
    "You canceled the request to link {circle} with {remote}" : "Ju anuluat kërkesën për të lidhur {circle} me {remote}",
    "{author} canceled the request to link {circle} with {remote}" : "{author} anuloi kërkesën për të lidhur {circle} me {remote}",
    "You accepted the request to link {remote} with {circle}" : "Ju pranuat kërkesën për të lidhur {remote} me {circle}",
    "{author} accepted the request to link {remote} with {circle}" : "{author} pranoi kërkesën për të lidhur {remote} me {circle}",
    "A link between {circle} and {remote} is now up and running" : "Një lidhje mes {circle} dhe {remote} është në funksionim.",
    "The link between {circle} and {remote} has been shutdown remotely" : "Një lidhje mes {circle} dhe {remote} është mbyllur në distancë",
    "You closed the link between {circle} and {remote}" : "Ju mbyllët lidhjen mes {circle} dhe {remote}",
    "{author} closed the link between {circle} and {remote}" : "{author} mbylli lidhjen mes {circle} dhe {remote}",
    "You joined {circle}" : "Ju iu bashkuat {circle}",
    "{member} joined {circle}" : "{member} iu bashkua {circle}",
    "You accepted the invitation to join {circle}" : "Ju pranuat ftesën për t'u bashkuar {circle}",
    "{member} accepted the invitation to join {circle}" : "{anëtar} pranoi ftesën për tu bashkuar {rreth}",
    "You added {member} as member to {circle}" : "Ju shtuat {member} si anëtar në {circle}",
    "You have been added as member to {circle} by {author}" : "Ju u shtuat si anëtar në {circle} nga {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} u shtua si anëtar në {circle} nga {author}",
    "You added {external} to {circle}" : "Ju shtuat {external} te {circle}",
    "{external} has been added to {circle} by {author}" : "{external} u shtua si anëtar në {circle} nga {author}",
    "You accepted {member}'s request to join {circle}" : "Ju e pranuat {member}'s kërkesën për tu bashkuar {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Kërkesa juaj për tu bashkuar{rreth} është pranuar nga {autor}",
    "You left {circle}" : "Ju latë {circle}",
    "{member} left {circle}" : "{member} la {circle}",
    "You declined the invitation to join {circle}" : "Ju refuzuat ftesën për t'u bashkuar {circle}",
    "{member} declined an invitation to join {circle}" : "{member} refuzoi ftesën për tu bashkuar {circle}",
    "You removed {member} from {circle}" : "Ju hoqët {member} nga {circle}",
    "You changed {member}'s level in {circle} to %1$s" : "ju ndryshuat nivelin e {member} në {circle} në %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} ndryshoi nivelin tuaj në {circle} në %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} ndryshoi nivelin e {member} në {circle} në %1$s",
    "{member} sent a request to join {circle}" : "{member} dërgoi një kërkesë për t'ju bashkuar {circle}",
    "You are the new owner of {circle}" : "Ju jeni pronari i ri i {circle}",
    "{member} is the new owner of {circle}" : "{member} është zoteruesi i ri i {rrethit}",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Çdo ngjarje e rëndësishme në një <strong>Rreth</strong> ju po e moderoni",
    "Personal" : "Personale",
    "Contact" : "Kontakt",
    "Circle" : "Rreth",
    "Member" : "Anëtar",
    "Moderator" : "Moderator",
    "Admin" : "Administratori",
    "Owner" : "Zotëruesi",
    "%s shared »%s« with you." : "1 %s ndarë »1 %s« me ju.",
    "%s on %s" : "%s në %s",
    "Password to access »%s«" : "Fjalëkalimi për akses »%s«",
    "Click the button below to open it." : "Kliko butonin më poshtë për të hapur atë.",
    "Open »%s«" : "Hap »%s«",
    "Circle not found" : "Rrethi nuk u gjet",
    "A circle with that name exists" : "Një rreth me këtë emër ekziston",
    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "Ju nuk mund të përdorni Aplikacionin e Qarqeve derisa administratori juaj të ketë lejuar të paktën një lloj qarku",
    "This member does not exist" : "Ky anëtar nuk ekziston",
    "This user is already a member of the circle" : "Ky  përdorues është tashmë anëtar i rrethit",
    "Federated link not found" : "Lidhja federative nuk u gjet",
    "This feature is not available for personal circles" : "Ky funksion nuk është i vlefshëm për rrathë personal.",
    "You cannot join this circle" : "Ju nuk mund t'i bashkoheni këtij rrethi",
    "This member is not a moderator" : "Ky anëtar nuk është moderator",
    "This member is the owner of the circle" : "Ky anëtar është zotëruesi i rrethit",
    "You are already a member of this circle" : "Ju jeni tashmë anëtar i këtij rrethi",
    "You have been blocked from this circle" : "Ju jeni bllokuar nga ky rreth",
    "Accept" : "Prano",
    "You need a specify a type of circle" : "Duhet të specifikoni një tip rrethi",
    "This member is not the owner of the circle" : "Ky anëtar nuk është zotëruesi i rrethit",
    "This group does not exist" : "Ky grup nuk ekziston",
    "This group is already linked to the circle" : "Ky grup është i lidhur tashmë me rrethin",
    "You cannot edit level in a personal circle" : "Nuk mund të modifikoni nivelin në një rreth personal",
    "Group cannot be set as owner of a circle" : "Grupi nuk mund të vendosej si zotërues i një rrethi",
    "now" : "tani",
    "This user does not exist" : "Ky përdorues nuk ekziston",
    "Could not find share" : "Nuk mund të gjej shpërndarje",
    "No files in here" : "Jo dosje këtu",
    "No entries found in this folder" : "Në këtë dosje nuk gjëndet asnjë hyrje",
    "Name" : "Emër",
    "Size" : "Madhësi",
    "Modified" : "Modifikuar ",
    "Are you sure you want to transfer your ownership?" : "A jeni të sigurtë se doni ta transferoni zotërimin tuaj?",
    "This action is irreversible" : "Ky veprim është i pakthyeshëm ",
    "Personal circle" : "Rreth personal",
    "Secret circle" : "Rreth sekret",
    "Closed circle" : "Rreth i mbyllur",
    "Public circle" : "Rreth publik",
    "Link Removed" : "Link-u është hequr",
    "Link down" : "Lidh poshtë",
    "Setting link" : "Vendosja e lidhjes",
    "Request dismissed" : "Kërkesa shkarkohet ",
    "Request sent" : "Kërkesa është dërguar",
    "Link requested" : "Link i kërkuar",
    "Link up" : "Bashkohu ",
    "Personal Circle" : "Rreth personal",
    "Secret Circle" : "Rreth sekret",
    "Closed Circle" : "Rreth i mbyllur",
    "Public Circle" : "Rreth Publik",
    "Secret" : "Sekret",
    "Closed" : "I mbyllur",
    "Public" : "Publik",
    "Not a member" : "S'është anëtar ",
    "Unknown" : "I panjohur",
    "Invited" : "I ftuar",
    "Requesting" : "Duke kerkuar",
    "Blocked" : "I bllokuar",
    "Kicked" : "I nxjerrë jashtë",
    "This operation will add/invite all members of the group to the circle" : "Ky veprim do të shtojë/ftojë të gjithë anëtarët e grupit në rreth",
    "Please confirm" : "Ju lutem konfirmoni",
    "Are you sure you want to leave this circle?" : "Jeni i sigurtë që doni ta lini këtë rreth?",
    "Are you sure you want to delete this circle?" : "Jeni i sigurtë që doni ta fshini këtë rreth?",
    "Mail Address" : "Adresa e postës elektronike",
    "Kick this member" : "Dëboje këtë anëtar",
    "Accept the request" : "Prano kërkesën",
    "Dismiss the request" : "Hidh poshtë kërkesën",
    "Unlink this group" : "Shkëputeni këtë grup",
    "Remove this link" : "Hiq këtë lidhje",
    "Cancel the link request" : "Anulo kërkesën për lidhje",
    "Accept the link request" : "Prano kërkesën për lidhje",
    "Reject the link request" : "Refuzo kërkesën për lidhje",
    "Cannot join this circle" : "Nuk mund të bashkohet me këtë rreth",
    "no error message" : "asnjë mesazh gabimi ",
    "You have joined this circle" : "Ju i jeni bashkuar këtij rrethi",
    "You have requested to join this circle" : "Keni kërkuar për tu bashkuar në  këtë rreth ",
    "You have left this circle" : "Ju e keni lënë këtë rreth",
    "Cannot leave this circle" : "S'mund të largoheni nga ky rreth ",
    "You have deleted this circle" : "Ju e keni fshirë këtë rreth",
    "Cannot delete this circle" : "Nuk mund të fshihej ky rreth",
    " {type} '{name}' created" : "{type}'{name}' u krijua",
    " {type} '{name}' could not be created" : " {lloji} '{emri}' nuk mund të krijohej",
    "Issue while retrieving the details of this circle" : "Problem gjatë marrjes së detajeve të këtij rrrethi",
    "Issue while retrieving the list of circles" : "Problem gjatë marrjes së listës së qarqeve",
    "Group '{name}' successfully added to the circle" : "Shtimi i grupit '{name}' është kryer me sukses. ",
    "Group '{name}' could not be added to the circle" : "'{Emri}' i grupit nuk mund të shtohej në rreth",
    "Group '{name}' updated" : "'{Emri}' i grupit u përditësua",
    "Group '{name}' could not be updated" : "'{Emri}' i grupit nuk mund të përditësohej",
    "Group '{name}' successfully removed from the circle" : "'{Emri}' i grupit u hoq nga rrethi me sukses",
    "Group '{name}' could not be removed from the circle" : "'{Emri}' i grupit nuk mund të hiqej nga rrethi",
    "A link to <b>{remote}</b> could not be initiated" : "Një lidhje me <b> {remote} </b> nuk mund të iniciohej",
    "A link to <b>{remote}</b> has been requested." : "Një link tek <b>{remote}</b> është kërkuar.",
    "the link to <b>{remote}</b> is now up and running." : "lidhja me <b> {remote} </b> tani është në funksionim.",
    "The status of the link could not be updated" : "Statusi i linkut nuk mund të përditësohej",
    "The status of the link has been updated" : "Statusi i linkut është përditësuar",
    "Members of the group '{name}' were added to the circle" : "Anëtarët e grupit '{name}' u shtuan në rreth",
    "Members of the group '{name}' could not be added to the circle" : "Anëtarët e grupit '{name}' nuk mund të shtoheshin në rreth",
    "Members of the group '{name}' were invited to the circle" : "Anëtarët e grupit '{name}' u ftuan në rreth",
    "Members of the group '{name}' could not be invited to the circle" : "Anëtarët e grupit '{name}' nuk mund të ftohen në rreth",
    "Issue while saving settings" : "Problem gjatë ruajtjes së konfigurimeve",
    "Settings saved." : "Konfigurimet u ruajtën",
    "The name of your circle must contain at least 3 characters" : "Emri i rrethit tuaj duhet të përmbajë të paktën 3 karakterë",
    "Linked Groups are not allowed on this Nextcloud" : "Grupet e lidhura nuk janë të lejuara në këtë Nextcloud",
    "Federated circles are not allowed on this Nextcloud" : "Qarqet e federuara nuk janë të lejuara në këtë Nextcloud",
    "Sharing Frame does not exist" : "Korniza e shpërndarjes nuk ekziston",
    "You cannot create this type of circle" : "Nuk mund të krijoni këtë tip rrethi",
    "You cannot display this type of circle" : "Nuk mund të shfaqni këtë tip rrethi",
    "Federated link does not have a valid format" : "Lidhja federative nuk ka një format të vlefshëm",
    "Federated circles are not allowed on the remote Nextcloud" : "Qarqet e federuara nuk janë të lejuara në Nextcloud në distancë",
    "This link exists already" : "Liku është ekzistent",
    "The requested remote circle does not exist" : "Rrethi në distancë i kërkuar nuk ekziston më",
    "The remote host is down or the Circles app is not installed on it" : "Mikpritësi i largët është ka rënë ose aplikacioni i Qarqeve nuk është i instaluar në të",
    "Cannot proceed with this status update" : "Nuk mund të vazhdojë me këtë përditësim të statusit",
    "Create a new circle" : "Krijo një rreth të ri",
    "Create a personal circle" : "Krijo një rreth personal",
    "Create a public circle" : "Krijo një rreth publik",
    "A personal circle is a list of users known only to the owner." : "Një rreth personal është një listë përdoruesish të njohur vetëm për zotëruesin.",
    "A public circle is an open group visible to anyone willing to join." : "Një rreth publik është një grup i hapur i dukshëm për këdo që dëshiron të bashkohet.",
    "All circles" : "Të gjitha rrathët",
    "Search circles" : "Kërko rrathë",
    "No filter" : "Jo filtera",
    "Circles you belong to" : "Rrathët që ju i përkisni",
    "Circles you own" : "Rrathët që zotëroni",
    "No circle selected" : "Asnjë rreth nuk është zgjedhur",
    "Settings" : "Rregullimet",
    "Pending invitation to join this circle" : "Ftesë në pritje për t'u bashkuar me këtë rreth",
    "You have a pending request to join this circle" : "Ju keni një kërkesë në pritje për t'u bashkuar me këtë rreth",
    "Add a member" : "Shto një anëtar",
    "Link a group" : "Lidhni një grup",
    "Link a circle" : "Lidhni një rreth",
    "Join this circle" : "Bashkohu me këtë rreth",
    "Delete circle" : "Fshini rrethin",
    "Edit circle" : "Edito rrethin",
    "Accept the invitation" : "Prano ftesën",
    "Decline the invitation" : "Refuzo ftesën",
    "Leave this circle" : "Lëreni këtë rreth",
    "Link to a circle" : "Lidhuni me një rreth",
    "Return to menu" : "Kthehu te menyja",
    "Username" : "Emri i përdoruesit",
    "Level" : "Nivel",
    "Status" : "Status",
    "Joined" : "I lidhur",
    "Group Name" : "Emri i Grupit",
    "Link" : "Lidhja",
    "Linked" : "I lidhur",
    "Description" : "Përshkrim",
    "Change password" : "Ndryshoni fjalëkalimin",
    "Allow Federated Links" : "Lejo Linqet e Federuara",
    "Save settings" : "Ruaj konfigurimet"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.8-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/circles/l10n/sq.js <==
OC.L10N.register(
    "circles",
    {
    "You deleted {circle}" : "Ju fshitë {circle}",
    "{author} deleted {circle}" : "{author} fshiu {circle}",
    "You removed {member} from {circle}" : "Ju hoqët {member} nga {circle}",
    "You joined {circle}" : "Ju iu bashkuat {circle}",
    "{member} joined {circle}" : "{member} iu bashkua {circle}",
    "You accepted the invitation to join {circle}" : "Ju pranuat ftesën për t'u bashkuar {circle}",
    "{member} accepted the invitation to join {circle}" : "{anëtar} pranoi ftesën për tu bashkuar {rreth}",
    "You added {member} as member to {circle}" : "Ju shtuat {member} si anëtar në {circle}",
    "You have been added as member to {circle} by {author}" : "Ju u shtuat si anëtar në {circle} nga {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} u shtua si anëtar në {circle} nga {author}",
    "You added {external} to {circle}" : "Ju shtuat {external} te {circle}",
    "{external} has been added to {circle} by {author}" : "{external} u shtua si anëtar në {circle} nga {author}",
    "You accepted {member}'s request to join {circle}" : "Ju e pranuat {member}'s kërkesën për tu bashkuar {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Kërkesa juaj për tu bashkuar{rreth} është pranuar nga {autor}",
    "You left {circle}" : "Ju latë {circle}",
    "{member} left {circle}" : "{member} la {circle}",
    "You declined the invitation to join {circle}" : "Ju refuzuat ftesën për t'u bashkuar {circle}",
    "{member} declined an invitation to join {circle}" : "{member} refuzoi ftesën për tu bashkuar {circle}",
    "You changed {member}'s level in {circle} to %1$s" : "ju ndryshuat nivelin e {member} në {circle} në %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} ndryshoi nivelin tuaj në {circle} në %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} ndryshoi nivelin e {member} në {circle} në %1$s",
    "{member} sent a request to join {circle}" : "{member} dërgoi një kërkesë për t'ju bashkuar {circle}",
    "You are the new owner of {circle}" : "Ju jeni pronari i ri i {circle}",
    "{member} is the new owner of {circle}" : "{member} është zoteruesi i ri i {rrethit}",
    "Personal" : "Personale",
    "System" : "Sistem",
    "Visible" : "I dukshëm",
    "Password protected" : "Mbrojtur me fjalëkalim",
    "Hidden" : "I fshehur",
    "Local" : "Lokale",
    "Root" : "Rrënjë",
    "Federated" : "Federated",
    "Contact" : "Kontakt",
    "Circle" : "Rreth",
    "Member" : "Anëtar",
    "Moderator" : "Moderator",
    "Admin" : "Administratori",
    "Owner" : "Zotëruesi",
    "%s shared »%s« with you." : "1 %s ndarë »1 %s« me ju.",
    "%s on %s" : "%s në %s",
    "Password to access »%s«" : "Fjalëkalimi për akses »%s«",
    "Click the button below to open it." : "Kliko butonin më poshtë për të hapur atë.",
    "Open »%s«" : "Hap »%s«",
    "Files" : "Skedarë",
    "This feature is not available for personal circles" : "Ky funksion nuk është i vlefshëm për rrathë personal.",
    "This member is not a moderator" : "Ky anëtar nuk është moderator",
    "This member does not exist" : "Ky anëtar nuk ekziston",
    "You are already a member of this circle" : "Ju jeni tashmë anëtar i këtij rrethi",
    "You have been blocked from this circle" : "Ju jeni bllokuar nga ky rreth",
    "Accept" : "Prano",
    "%s" : "%s",
    "Open %s" : "Hap %s",
    "No files in here" : "Jo dosje këtu",
    "No entries found in this folder" : "Në këtë dosje nuk gjëndet asnjë hyrje",
    "Name" : "Emër",
    "Size" : "Madhësi",
    "Modified" : "Modifikuar "
},
"nplurals=2; plural=(n != 1);");
